@@ -2,8 +2,9 @@ import inspect
 import pathlib
 from functools import lru_cache
 from io import TextIOBase
-from typing import Sequence, Dict, Union, TypeVar, Optional, Literal
+from typing import Sequence, Union, TypeVar, Optional, Literal
 
+import polars as pl
 from black import Mode, format_str
 from loguru import logger
 from sympy import simplify, cse, symbols, numbered_symbols
@@ -108,10 +109,10 @@ class ExprTool:
         表达式列表
         """
         # 抽取前先化简
-        args = [(a, simplify2(b), c) for a, b, c in args]
+        args = [(k, simplify2(v), c) for k, v, c in args]
 
         # 保留了注释信息
-        exprs_syms = [(self.extract(b, date, asset), c) for a, b, c in args]
+        exprs_syms = [(self.extract(v, date, asset), c) for k, v, c in args]
         exprs = []
         syms = []
         for (e, s), c in exprs_syms:
@@ -124,7 +125,7 @@ class ExprTool:
         # 如果目标有重复表达式，这里会混乱
         exprs = sorted(set(exprs), key=exprs.index)
         # 这里不能合并简化与未简化的表达式，会导致cse时失败，需要简化表达式合并
-        exprs = exprs + [(b, c) for a, b, c in args]
+        exprs = exprs + [(v, c) for k, v, c in args]
 
         # print(exprs)
         syms = [str(s) for s in syms]
@@ -137,10 +138,10 @@ class ExprTool:
 
         # cse前简化一次，cse后不再简化
         # (~开盘涨停 & 昨收涨停) | (~收盘涨停 & 最高涨停)
-        for a, b in repl:
-            exprs_list.append((a, b, "#"))
-        for a, b, c in redu:
-            exprs_list.append((a, b, c))
+        for k, v in repl:
+            exprs_list.append((k, v, "#"))
+        for k, v, c in redu:
+            exprs_list.append((k, v, c))
 
         return exprs_list
 
@@ -166,9 +167,9 @@ class ExprTool:
             表达式
 
         """
-        self.exprs_names = [a for a, b, c in exprs_src]
+        self.exprs_names = [k for k, v, c in exprs_src]
         # 包含了注释信息
-        _exprs = [a for a, b in exprs]
+        _exprs = [k for k, v in exprs]
 
         # 注意：对于表达式右边相同，左边不同的情况，会当成一个处理
         repl, redu = cse(_exprs, symbols_repl, optimizations="basic")
@@ -196,12 +197,12 @@ class ExprTool:
             G = dag_middle(G, self.exprs_names, self.get_current_func, self.get_current_func_kwargs, date, asset)
         return dag_end(G)
 
-    def all(self, exprs_src, style: Literal['pandas', 'polars_group', 'polars_over'] = 'polars_over',
-            template_file: str = 'template.py.j2',
+    def all(self, exprs_src, style: Literal['pandas', 'polars_group', 'polars_over', 'sql'] = 'polars_over',
+            template_file: Optional[str] = None,
             replace: bool = True, regroup: bool = False, format: bool = True,
             date='date', asset='asset',
-            alias: Dict[str, str] = {},
             extra_codes: Sequence[object] = (),
+            table_name: str = 'self',
             **kwargs):
         """功能集成版，将几个功能写到一起方便使用
 
@@ -210,7 +211,7 @@ class ExprTool:
         exprs_src: list
             表达式列表
         style: str
-            代码风格。可选值 ('polars_group', 'polars_over', 'pandas')
+            代码风格。可选值 ('polars_group', 'polars_over', 'pandas', 'sql')
         template_file: str
             根据需求可定制模板
         replace:bool
@@ -223,8 +224,6 @@ class ExprTool:
             日期字段名
         asset:str
             资产字段名
-        alias: Dict[str,str]
-            符号别名。可以变通的传入正则符号名
         extra_codes: Sequence[object]
             需要复制到模板中的额外代码
 
@@ -233,7 +232,7 @@ class ExprTool:
         代码字符串
 
         """
-        assert style in ('pandas', 'polars_group', 'polars_over')
+        assert style in ('pandas', 'polars_group', 'polars_over', 'sql')
 
         if replace:
             exprs_src = replace_exprs(exprs_src)
@@ -248,24 +247,29 @@ class ExprTool:
         exprs_ldl, G = self.dag(True, date, asset)
 
         if regroup:
-            exprs_ldl.optimize()
+            exprs_ldl.optimize(merge=style != 'sql')
 
         if style == 'polars_group':
             from expr_codegen.polars_group.code import codegen
         elif style == 'polars_over':
             from expr_codegen.polars_over.code import codegen
-        else:
+        elif style == 'pandas':
             from expr_codegen.pandas.code import codegen
+        elif style == 'sql':
+            from expr_codegen.sql.code import codegen
+            format = False
+        else:
+            raise ValueError(f'unknown style {style}')
 
         extra_codes = [c if isinstance(c, str) else inspect.getsource(c) for c in extra_codes]
 
         codes = codegen(exprs_ldl, exprs_src, syms_dst,
                         filename=template_file, date=date, asset=asset,
-                        alias=alias,
                         extra_codes=extra_codes,
+                        table_name=table_name,
                         **kwargs)
 
-        logger.info(f'code is generated')
+        logger.info(f'{style} code is generated')
 
         if format:
             # 格式化。在遗传算法中没有必要
@@ -279,9 +283,10 @@ class ExprTool:
                   extra_codes: str,
                   output_file: str,
                   convert_xor: bool,
-                  style: Literal['pandas', 'polars_group', 'polars_over'] = 'polars_over',
-                  template_file: str = 'template.py.j2',
+                  style: Literal['pandas', 'polars_group', 'polars_over', 'sql'] = 'polars_over',
+                  template_file: Optional[str] = None,
                   date: str = 'date', asset: str = 'asset',
+                  table_name: str = 'self',
                   **kwargs) -> str:
         """通过字符串生成代码， 加了缓存，多次调用不重复生成"""
         raw, exprs_list = sources_to_exprs(self.globals_, source, *more_sources, convert_xor=convert_xor)
@@ -295,6 +300,7 @@ class ExprTool:
                                           # 传入多个列的方法
                                           extra_codes,
                                           ),
+                             table_name=table_name,
                              **kwargs)
 
         # 移回到cache，防止多次调用多次保存
@@ -311,8 +317,8 @@ class ExprTool:
 
 
 @lru_cache(maxsize=64, typed=True)
-def _get_func_from_code(code: str):
-    logger.info(f'get func from code')
+def _get_func_from_code_py(code: str):
+    logger.info(f'get func from code py')
     globals_ = {}
     exec(code, globals_)
     return globals_['main']
@@ -327,7 +333,7 @@ def _get_func_from_module(module: str):
 
 
 @lru_cache(maxsize=64, typed=True)
-def _get_func_from_file(file: str):
+def _get_func_from_file_py(file: str):
     file = pathlib.Path(file)
     logger.info(f'get func from file "{file.absolute()}"')
     with open(file, 'r', encoding='utf-8') as f:
@@ -336,6 +342,14 @@ def _get_func_from_file(file: str):
         return globals_['main']
 
 
+@lru_cache(maxsize=64, typed=True)
+def _get_code_from_file(file: str):
+    file = pathlib.Path(file)
+    logger.info(f'get code from file "{file.absolute()}"')
+    with open(file, 'r', encoding='utf-8') as f:
+        return f.read()
+
+
 _TOOL_ = ExprTool()
 
 
@@ -346,17 +360,18 @@ def codegen_exec(df: Optional[DataFrame],
                  output_file: Union[str, TextIOBase, None] = None,
                  run_file: Union[bool, str] = False,
                  convert_xor: bool = False,
-                 style: Literal['pandas', 'polars_group', 'polars_over'] = 'polars_over',
-                 template_file: str = 'template.py.j2',
+                 style: Literal['pandas', 'polars_group', 'polars_over', 'sql'] = 'polars_over',
+                 template_file: Optional[str] = None,
                  date: str = 'date', asset: str = 'asset',
-
-                 **kwargs) -> Optional[DataFrame]:
+                 table_name: str = 'self',
+                 **kwargs) -> Union[DataFrame, str, None]:
     """快速转换源代码并执行
 
     Parameters
     ----------
-    df: pl.DataFrame, pd.DataFrame, pl.LazyFrame
-        输入DataFrame
+    df: pl.DataFrame, pd.DataFrame, pl.LazyFrame,None
+        输入DataFrame，输出DataFrame
+        输入None，输出代码
     codes:
         函数体。此部分中的表达式会被翻译成目标代码
     extra_codes: str
@@ -372,9 +387,10 @@ def codegen_exec(df: Optional[DataFrame],
     convert_xor: bool
         ^ 转成异或还是乘方
     style: str
-        代码风格。可选值 'pandas', 'polars_group', 'polars_over'
+        代码风格。可选值 'pandas', 'polars_group', 'polars_over', 'sql'
         - polars_group: 不支持Lazy
         - pandas: 不支持struct
+        - sql: 只生成sql语句，不执行
     template_file: str
         代码模板
     date: str
@@ -386,10 +402,15 @@ def codegen_exec(df: Optional[DataFrame],
         - partition_by: 空值划分到不同分区
         - order_by: 空值排同一分区的前排
         - None: 不做处理
+    table_name:str
+        表名。style=sql时有效
 
     Returns
     -------
     DataFrame
+        输出DataFrame
+    str
+        输出代码
 
     Notes
     -----
@@ -400,16 +421,24 @@ def codegen_exec(df: Optional[DataFrame],
 
     """
     if df is not None:
+        input_file = None
         # 以下代码都带缓存功能
         if run_file is True:
             assert output_file is not None, 'output_file is required'
-            return _get_func_from_file(output_file)(df)
-        if run_file is not False:
-            run_file = str(run_file)
-            if run_file.endswith('.py'):
-                return _get_func_from_file(run_file)(df)
+            input_file = str(output_file)
+        elif run_file is not False:
+            input_file = str(run_file)
+
+        if input_file is not None:
+            if input_file.endswith('.py'):
+                return _get_func_from_file_py(input_file)(df)
+            elif input_file.endswith('.sql'):
+                ctx = pl.SQLContext(frames={table_name: df})
+                return ctx.execute(_get_code_from_file(input_file), eager=isinstance(df, _pl_DataFrame))
             else:
-                return _get_func_from_module(run_file)(df)  # 可断点调试
+                return _get_func_from_module(input_file)(df)  # 可断点调试
+    else:
+        pass
 
     # 此代码来自于sympy.var
     frame = inspect.currentframe().f_back
@@ -426,11 +455,16 @@ def codegen_exec(df: Optional[DataFrame],
         style=style, template_file=template_file,
         date=date, asset=asset,
         over_null=over_null,
+        table_name=table_name,
         **kwargs
     )
 
     if df is None:
-        return None
+        # 如果df为空，直接返回代码
+        return code
+    elif style == 'sql':
+        ctx = pl.SQLContext(frames={table_name: df})
+        return ctx.execute(code, eager=isinstance(df, _pl_DataFrame))
     else:
         # 代码一样时就从缓存中取出函数
-        return _get_func_from_code(code)(df)
+        return _get_func_from_code_py(code)(df)
